###############################################################################
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
###############################################################################
# Licensed Materials - Property of IBM
#
#  5724-T01 5724-S98
#
# (c) Copyright IBM Corp. 2003, 2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###############################################################################

package EngineConfig;

@ISA    = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();

#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = (
	{
		'RULE_TYPE'               => 'ASN1_3GPP_INTERFACE',
		'RULE_DESC'               => 'ASN1 Ericsson R10 APG40 Interface',
		'INPUT_FILE_DESCRIPTION'  => ['^C.*'],
		'INPUT_DIR_DEPTH'         => 5,
		'DIRECTORY_HEADER_FIELDS' => {
			REGION_ID  => '\/REGION_?([^\/]+)\/?',
			NETWORK_ID => '\/NETWORK_?([^\/]+)\/?',
		},
		'FILENAME_HEADER_FIELDS' => {

			# !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
			# !!!! Please make sure only ONE NODEID entry is !!!!
			# !!!! uncommented below			 !!!!
			# !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
			# For meteor
			#'NODEID'    => '^C\d{8}\.\d{4}\-\d{8}\.\d{4}_([a-zA-Z0-9]+)[^a-zA-Z0-9].*',
			#For ATT
			'NODEID' => '^C\d{8}\.\d{4}\-\d{8}\.\d{4}_(.+)$',

			'START_DATE' => '^C(\d{8})\.\d{4}\-\d{8}\.\d{4}_.+',
			'START_TIME' => '^C\d{8}\.(\d{4})\-\d{8}\.\d{4}_.+',

			#'END_TIME'  => '^\w{1}\d{8}\.\d{4}.\d{8}.(\d{4}).*',

		},

		#'ASN1_EXTRACT_TOOL' => '../parsersrc/dumpasn1',
		#'ASN1_EXTRACT_TOOL' => '/home/metrica/asn_gateway/bin/asn1dump',
		#'ASN1_EXTRACT_TOOL_PARAMETERS' => '-p',
		'ASN1_ENABLE_EXTRACT_TO_TEMP_FILE' => 0,
		'ASN1_DATA_FORMAT'                 => [
			[ 'fileFormatVersion', 'senderName', 'senderType', 'vendorName', 'collectionBeginTime' ],
			[ [ 'nEUserName', 'nEDistinguishedName' ], [ 'measTimeStamp', 'granularityPeriod', 'measType', [ 'measObjInstId', [ 'iValue', 'rValue', 'noValue' ], 'suspectFlag' ], ], ],
			'measFileFooter',
		],

		'ASN1_OBJECT_INSTANCE_ID_ELEMENT_NAME' => 'measObjInstId',
		'ASN1_HEADER_INFO_FOR_PIF_FILENAME'    => [ 'NODEID', 'START_DATE', 'START_TIME' ],

		#'ASN1_HEADER_INFO_FOR_PIF_FILENAME' =>
		#    ['measTimeStamp_Date',
		#     'measTimeStamp_Time',
		#     'senderName_managedElementId',
		#     'nEDistinguishedName_managedElementId',
		#     'NODEID',
		#     'Type'],
		'ASN1_PIF_HEADER_ELEMENT_NAMES' => [    #'fileFormatVersion',
			                                    #'senderName',
			                                    #'senderType',
			                                    #'vendorName',
			'collectionBeginTime',

			#'nEUserName',
			#'nEDistinguishedName',
			'measTimeStamp',
			'granularityPeriod'
		],
		'ASN1_UNIQUE_PIF_BLOCK_ELEMENT_NAME'  => 'measTimeStamp',
		'ASN1_COUNTER_NAMES'                  => 'measType',
		'ASN1_COUNTER_VALUES'                 => '\w+Value',
		'ASN1_SUSPECT_FLAG_ELEMENT_NAME'      => 'suspectFlag',
		'ASN1_ALTERNATIVE_COUNTER_NULL_VALUE' => '-9999',
		'ASN1_HEX_TO_DECIMAL_ELEMENTS'        => [ 'granularityPeriod', 'iValue' ],

		#'ASN1_HEX_TO_CHAR_ELEMENTS' => ['senderType'],

		'ASN1_OUTPUT_BLOCK_ELEMENT_NAME' => 'measObjInstId',
		'ASN1_3GPP_FILENAME_VALIDATION'  => {
			Type      => '^(A|B|C|D).+$',
			StartDate => '^\w{1}(\d{8}).+$',
			StartTime => '^\w{1}\d{8}\.(\d{4}).+$',
		},

		'ASN1_OBJECT_INSTANCE_ID_DESCRIPTION' => {

			"BSCGPRS"    => '\'BSCGPRS\.(\w*.*)\'',
			"BSCGPRS2"   => '\'BSCGPRS2\.(\w*.*)\'',
			"CCCHLOAD"   => '\'CCCHLOAD\.(\w*.*)\'',
			"CELEVENTD"  => '\'CELEVENTD\.(\w*.*)\'',
			"CELEVENTH"  => '\'CELEVENTH\.(\w*.*)\'',
			"CELEVENTI"  => '\'CELEVENTI\.(\w*.*)\'',
			"CELEVENT1"  => '\'CELEVENT1\.(\w*.*)\'',
			"CELLGPRS"   => '\'CELLGPRS\.(\w*.*)\'',
			"CELLGPRS2"  => '\'CELLGPRS2\.(\w*.*)\'',
			"CELLPAG"    => '\'CELLPAG\.(\w*.*)\'',
			"CELLQOSG"   => '\'CELLQOSG\.(\w*.*)\'',
			"CELTCHF"    => '\'CELTCHF\.(\w*.*)\'',
			"CELTCHH"    => '\'CELTCHH\.(\w*.*)\'',
			"CLTCH"      => '\'CLTCH\.(\w*.*)\'',
			"CLTCHDRF"   => '\'CLTCHDRF\.(\w*.*)\'',
			"CLTCHDRH"   => '\'CLTCHDRH\.(\w*.*)\'',
			"LOADREG"    => '\'LOADREG\.(\w*.*)\'',
			"LOAS"       => '\'LOAS\.(\w*.*)\'',
			"NCELLREL"   => '\'NCELLREL\.(\w*.*)\'',
			"NICELASS"   => '\'NICELASS\.(\w*.*)\'',
			"NICELHO"    => '\'NICELHO\.(\w*.*)\'',
			"RANDOMACC"  => '\'RANDOMACC\.(\w*.*)\'',
			"RNDACCEXT"  => '\'RNDACCEXT\.(\w*.*)\'',
			"TRAFDLGPRS" => '\'TRAFDLGPRS\.(\w*.*)\'',
			"TRAFGPRS2"  => '\'TRAFGPRS2\.(\w*.*)\'',
			"C7SIO"      => '\'C7SIO\.(\w*.*)\'',
			"C7SL1"      => '\'C7SL1\.(\w*.*)\'',
			"C7SL2"      => '\'C7SL2\.(\w*.*)\'',
			"C7LSSI"     => '\'C7LSSI\.(\w*.*)\'',
			"C7DPCSIO"   => '\'C7DPCSIO\.(\w*.*)\'',
			"C7OD"       => '\'C7OD\.(\w*.*)\'',
			"C7ODS"      => '\'C7ODS\.(\w*.*)\'',
			"C7OPCDS"    => '\'C7OPCDS\.(\w*.*)\'',
			"C7OPCSIO"   => '\'C7OPCSIO\.(\w*.*)\'',
			"C7RTSET"    => '\'C7RTSET\.(\w*.*)\'',
			"C7SCSUBSYS" => '\'C7SCSUBSYS\.(\w*.*)\'',
			"C7SCSIGP"   => '\'C7SCSIGP\.(\w*.*)\'',
			"C7SLSET"    => '\'C7SLSET\.(\w*.*)\'',
			"C7SPNT"     => '\'C7SPNT\.(\w*.*)\'',
			"HS7SL1"     => '\'HS7SL1\.(\w*.*)\'',
			"SS7SLMT1"   => '\'SS7SLMT1\.(\w*.*)\'',
			"SS7SLMT2"   => '\'SS7SLMT2\.(\w*.*)\'',
			"SS7LS"      => '\'SS7LS\.(\w*.*)\'',
			"SS7SLTRAFF" => '\'SS7SLTRAFF\.(\w*.*)\'',
			"SS7SCSUBSY" => '\'SS7SCSUBSY\.(\w*.*)\'',
			"SS7TT"      => '\'SS7TT\.(\w*.*)\'',
			"SS7PRGRP"   => '\'SS7PRGRP\.(\w*.*)\'',
			"SS7HSLPG1"  => '\'SS7HSLPG1\.(\w*.*)\'',
			"SS7HSLPG2"  => '\'SS7HSLPG2\.(\w*.*)\'',
			"SDIPMS"     => '\'SDIPMS\.(\w*.*)\'',
			"SDIPHP"     => '\'SDIPHP\.(\w*.*)\'',
			"SDIPLP"     => '\'SDIPLP\.(\w*.*)\'',
			"DIGPATH"    => '\'DIGPATH\.(\w*.*)\'',
			"GRPSWITCH"  => '\'GRPSWITCH\.(\w*.*)\'',
			"SNT"        => '\'SNT\.(\w*.*)\'',
			"DIGS"       => '\'DIGS\.(\w*.*)\'',
			"SPDL"       => '\'SPDL\.(\w*.*)\'',
			"NETWSYNC"   => '\'NETWSYNC\.(\w*.*)\'',
			"APDISKS"    => '\'APDISKS\.(\w*.*)\'',
			"APPLATFORM" => '\'APPLATFORM\.(\w*.*)\'',
			"SS7SCCPUSE" => '\'SS7SCCPUSE\.(\w*.*)\'',
			"SS7SCQOS"   => '\'SS7SCQOS\.(\w*.*)\'',
			"C7SCCPUSE"  => '\'C7SCCPUSE\.(\w*.*)\'',
			"C7SCPERF"   => '\'C7SCPERF\.(\w*.*)\'',
			"C7SCQOS"    => '\'C7SCQOS\.(\w*.*)\'',
			"ATERTRANS"  => '\'ATERTRANS\.(\w*.*)\'',
			"BSC"        => '\'BSC\.(\w*.*)\'',
			"BSCMSLOT"   => '\'BSCMSLOT\.(\w*.*)\'',
			"BSCPOS"     => '\'BSCPOS\.(\w*.*)\'',
			"BSCQOS"     => '\'BSCQOS\.(\w*.*)\'',
			"GPHLOADREG" => '\'GPHLOADREG\.(\w*.*)\'',
			"DELSTRTBF"  => '\'DELSTRTBF\.(\w*.*)\'',
			"LOASMISC"   => '\'LOASMISC\.(\w*.*)\'',
			"TRALOST"    => '\'TRALOST\.(\w*.*)\'',
			"MSC"        => '\'MSC\.(\w*.*)\'',
			"CP"         => '\'CP\.(\w*.*)\'',
			"EMGPRS"     => '\'EMGPRS\.(\w*.*)\'',
			"MOTG"       => '\'MOTG\.(\w*.*)\'',
			"MOTS"       => '\'MOTS\.(\w*.*)\'',
			"DOWNTIME"   => '\'DOWNTIME\.(\w*.*)\'',
			"CELEVENTSC" => '\'CELEVENTSC\.(\w*.*)\'',
			"CELLAFFER"  => '\'CELLAFFER\.(\w*.*)\'',
			"CELLAHFER"  => '\'CELLAHFER\.(\w*.*)\'',
			"CELLCONF"   => '\'CELLCONF\.(\w*.*)\'',
			"CELLDUALT"  => '\'CELLDUALT\.(\w*.*)\'',
			"CELLEFFER"  => '\'CELLEFFER\.(\w*.*)\'',
			"CELLFERF"   => '\'CELLFERF\.(\w*.*)\'',
			"CELLFERH"   => '\'CELLFERH\.(\w*.*)\'',
			"CELLFFER"   => '\'CELLFFER\.(\w*.*)\'',
			"CELLFLXAB"  => '\'CELLFLXAB\.(\w*.*)\'',
			"CELLGPRSO"  => '\'CELLGPRSO\.(\w*.*)\'',
			"CELLHFER"   => '\'CELLHFER\.(\w*.*)\'',
			"CELLQOSEG"  => '\'CELLQOSEG\.(\w*.*)\'',
			"CELLQOSS"   => '\'CELLQOSS\.(\w*.*)\'',
			"CELLSQI"    => '\'CELLSQI\.(\w*.*)\'',
			"CELLSQIDL"  => '\'CELLSQIDL\.(\w*.*)\'',
			"CLTCHFV1"   => '\'CLTCHFV1\.(\w*.*)\'',
			"CLTCHFV2"   => '\'CLTCHFV2\.(\w*.*)\'',
			"CLTCHHV1"   => '\'CLTCHHV1\.(\w*.*)\'',
			"CLDTMEST"   => '\'CLDTMEST\.(\w*.*)\'',
			"CLDTMPER"   => '\'CLDTMPER\.(\w*.*)\'',
			"CLDTMQOS"   => '\'CLDTMQOS\.(\w*.*)\'',
			"CLRATECHG"  => '\'CLRATECHG\.(\w*.*)\'',
			"CLRXQUAL"   => '\'CLRXQUAL\.(\w*.*)\'',
			"CELEVENTS"  => '\'CELEVENTS\.(\w*.*)\'',
			"CELLCCHDR"  => '\'CELLCCHDR\.(\w*.*)\'',
			"CELLCCHHO"  => '\'CELLCCHHO\.(\w*.*)\'',
			"CLSDCCH"    => '\'CLSDCCH\.(\w*.*)\'',
			"CLSDCCHO"   => '\'CLSDCCHO\.(\w*.*)\'',
			"CLSMS"      => '\'CLSMS\.(\w*.*)\'',
			"CELLHCS"    => '\'CELLHCS\.(\w*.*)\'',
			"CELTCH"     => '\'CELTCH\.(\w*.*)\'',
			"CLTCHFV3"   => '\'CLTCHFV3\.(\w*.*)\'',
			"CLTCHFV3C"  => '\'CLTCHFV3C\.(\w*.*)\'',
			"IDLEOTCHF"  => '\'IDLEOTCHF\.(\w*.*)\'',
			"IDLEUTCHF"  => '\'IDLEUTCHF\.(\w*.*)\'',
			"IDLEOTCHH"  => '\'IDLEOTCHH\.(\w*.*)\'',
			"IDLEUTCHH"  => '\'IDLEUTCHH\.(\w*.*)\'',
			"CELLEIT"    => '\'CELLEIT\.(\w*.*)\'',
			"CELLEIT2"   => '\'CELLEIT2\.(\w*.*)\'',
			"CELLGPRS3"  => '\'CELLGPRS3\.(\w*.*)\'',
			"CELLGPRS4"  => '\'CELLGPRS4\.(\w*.*)\'',
			"CELTCHFP"   => '\'CELTCHFP\.(\w*.*)\'',
			"NUCELLREL"  => '\'NUCELLREL\.(\w*.*)\'',
			"CELLHSCSD"  => '\'CELLHSCSD\.(\w*.*)\'',
			"PREEMP"     => '\'PREEMP\.(\w*.*)\'',
			"CELLMSQ"    => '\'CELLMSQ\.(\w*.*)\'',
			"CLQOSSCON"  => '\'CLQOSSCON\.(\w*.*)\'',
			"CLQOSSCON2" => '\'CLQOSSCON2\.(\w*.*)\'',
			"CHGRP0SQI"  => '\'CHGRP0SQI\.(\w*.*)\'',
			"CHGRP0F"    => '\'CHGRP0F\.(\w*.*)\'',
			"CHGRP0H"    => '\'CHGRP0H\.(\w*.*)\'',
			"CLTCHDRAF"  => '\'CLTCHDRAF\.(\w*.*)\'',
			"CLTCHDRAH"  => '\'CLTCHDRAH\.(\w*.*)\'',
			"CLTCHHV3C"  => '\'CLTCHHV3C\.(\w*.*)\'',
			"CLTCHHV3"   => '\'CLTCHHV3\.(\w*.*)\'',
			"RLINKBITR"  => '\'RLINKBITR\.(\w*.*)\'',
			"NECELLREL"  => '\'NECELLREL\.(\w*.*)\'',
			"NECELASS"   => '\'NECELASS\.(\w*.*)\'',
			"NECELHO"    => '\'NECELHO\.(\w*.*)\'',
			"NECELHOEX"  => '\'NECELHOEX\.(\w*.*)\'',
			"NECELHO"    => '\'NECELHO\.(\w*.*)\'',
			"NICELHOEX"  => '\'NICELHOEX\.(\w*.*)\'',
			"ABISIP"     => '\'ABISIP\.(\w*.*)\'',
			"NONRES64K"  => '\'NONRES64K\.(\w*.*)\'',
			"RES64K"     => '\'RES64K\.(\w*.*)\'',
			"SUPERCH"    => '\'SUPERCH\.(\w*.*)\'',
			"CELLMSCAP"  => '\'CELLMSCAP\.(\w*.*)\'',
			"SPHD"       => '\'SPHD\.(\w*.*)\'',
			"EMSTAT"     => '\'EMSTAT\.(\w*.*)\'',
			"LAPD"       => '\'LAPD\.(\w*.*)\'',
			"TRAPCOM"    => '\'TRAPCOM\.(\w*.*)\'',
			"TRASEVENT"  => '\'TRASEVENT\.(\w*.*)\'',
			"TRAPEVENT"  => '\'TRAPEVENT\.(\w*.*)\'',
			"CLTCHHV2"   => '\'CLTCHHV2\.(\w*.*)\'',
			"CLVGCSEST"  => '\'CLVGCSEST\.(\w*.*)\'',
			"TRAFGPRS3"  => '\'TRAFGPRS3\.(\w*.*)\'',
			"CELLPOS"    => '\'CELLPOS\.(\w*.*)\'',
			"DIP"        => '\'DIP\.(\w*.*)\'',
			"TRASUBPOOL" => '\'TRASUBPOOL\.(\w*.*)\'',
			"TRAFULGPRS" => '\'TRAFULGPRS\.(\w*.*)\'',
############### NEW for R1207B ################
			"SPSP"       => '\'SPSP\.(\w*.*)\'',
			"PGW"        => '\'PGW\.(\w*.*)\'',
			"PGWLDIST"   => '\'PGWLDIST\.(\w*.*)\'',
			"SUPERCH2"   => '\'SUPERCH2\.(\w*.*)\'',
			"TRH"        => '\'TRH\.(\w*.*)\'',
			"SS7TOTAL"   => '\'SS7TOTAL\.(\w*.*)\'',
			"SS7TOTAL2"  => '\'SS7TOTAL2\.(\w*.*)\'',
			"SS7TIMERS"  => '\'SS7TIMERS\.(\w*.*)\'',
			"TCABO"      => '\'TCABO\.(\w*.*)\'',
			"TCREJ"      => '\'TCREJ\.(\w*.*)\'',
			"TCUSE"      => '\'TCUSE\.(\w*.*)\'',
			"TPLAT"      => '\'TPLAT\.(\w*.*)\'',
			"TCCMP"      => '\'TCCMP\.(\w*.*)\'',
			"TCDIA"      => '\'TCDIA\.(\w*.*)\'',
			"TCMSG"      => '\'TCMSG\.(\w*.*)\'',
			"C7RTTOTAL"  => '\'C7RTTOTAL\.(\w*.*)\'',
			"GANDIREPA"  => '\'GANDIREPA\.(\w*.*)\'',
			"GANRESALL"  => '\'GANRESALL\.(\w*.*)\'',
			"GANRPLOAD"  => '\'GANRPLOAD\.(\w*.*)\'',
			"EMG"        => '\'EMG\.(\w*.*)\'',
			"EM"         => '\'EM\.(\w*.*)\'',
			"EMRP"       => '\'EMRP\.(\w*.*)\'',
			"CVTR02"     => '\'CVTR02\.(\w*.*)\'',
			"MRVFAIL"    => '\'MRVFAIL\.(\w*.*)\'',
			"SCTPAM"     => '\'SCTPAM\.(\w*.*)\'',
			"SCTPLM"     => '\'SCTPLM\.(\w*.*)\'',
			"SS7HSLS"    => '\'SS7HSLS\.(\w*.*)\'',
			"SS7HSLTRAF" => '\'SS7HSLTRAF\.(\w*.*)\'',
			"SS7HSLMT1"  => '\'SS7HSLMT1\.(\w*.*)\'',
			"SS7HSLMT2"  => '\'SS7HSLMT2\.(\w*.*)\'',
			"SS7HSLMT3"  => '\'SS7HSLMT3\.(\w*.*)\'',
			"RP"         => '\'RP\.(\w*.*)\'',
			"C7ADJSLP"   => '\'C7ADJSLP\.(\w*.*)\'',
			"C7DPC"      => '\'C7DPC\.(\w*.*)\'',
			"C7OPC"      => '\'C7OPC\.(\w*.*)\'',
		},
############### END ########################

		'ASN1_ALT_OBJECT_INSTANCE_ID_NAMES' => {
			"TRASUBPOOL" => ['OBJ_ID'],
			"DIP"        => ['OBJ_ID'],
			"BSCGPRS"    => ['OBJ_ID'],
			"CELLPOS"    => ['OBJ_ID'],
			"SPHD"       => ['OBJ_ID'],
			"EMSTAT"     => ['OBJ_ID'],
			"LAPD"       => ['OBJ_ID'],
			"TRAPCOM"    => ['OBJ_ID'],
			"TRASEVENT"  => ['OBJ_ID'],
			"TRAPEVENT"  => ['OBJ_ID'],
			"CLTCHHV2"   => ['OBJ_ID'],
			"CLVGCSEST"  => ['OBJ_ID'],
			"BSCGPRS2"   => ['OBJ_ID'],
			"CCCHLOAD"   => ['OBJ_ID'],
			"TRAFGPRS3"  => ['OBJ_ID'],
			"CELEVENTD"  => ['OBJ_ID'],
			"CELEVENTH"  => ['OBJ_ID'],
			"CELEVENTI"  => ['OBJ_ID'],
			"CELEVENT1"  => ['OBJ_ID'],
			"CELLGPRS"   => ['OBJ_ID'],
			"CELLGPRS2"  => ['OBJ_ID'],
			"CELLPAG"    => ['OBJ_ID'],
			"CELLQOSG"   => ['OBJ_ID'],
			"CELTCHF"    => ['OBJ_ID'],
			"CELTCHH"    => ['OBJ_ID'],
			"CLTCH"      => ['OBJ_ID'],
			"CLTCHDRF"   => ['OBJ_ID'],
			"CLTCHDRH"   => ['OBJ_ID'],
			"LOADREG"    => ['OBJ_ID'],
			"LOAS"       => ['OBJ_ID'],
			"NCELLREL"   => ['OBJ_ID'],
			"NICELASS"   => ['OBJ_ID'],
			"NICELHO"    => ['OBJ_ID'],
			"RANDOMACC"  => ['OBJ_ID'],
			"RNDACCEXT"  => ['OBJ_ID'],
			"TRAFDLGPRS" => ['OBJ_ID'],
			"TRAFGPRS2"  => ['OBJ_ID'],
			"TRAFULGPRS" => ['OBJ_ID'],
			"C7SIO"      => ['OBJ_ID'],
			"C7SL1"      => ['OBJ_ID'],
			"C7SL2"      => ['OBJ_ID'],
			"C7DPCSIO"   => ['OBJ_ID'],
			"C7OD"       => ['OBJ_ID'],
			"C7ODS"      => ['OBJ_ID'],
			"C7OPCDS"    => ['OBJ_ID'],
			"C7OPCSIO"   => ['OBJ_ID'],
			"C7RTSET"    => ['OBJ_ID'],
			"C7SCSUBSYS" => ['OBJ_ID'],
			"C7SCSIGP"   => ['OBJ_ID'],
			"C7SLSET"    => ['OBJ_ID'],
			"C7SPNT"     => ['OBJ_ID'],
			"HS7SL1"     => ['OBJ_ID'],
			"SS7SLMT1"   => ['OBJ_ID'],
			"SS7SLMT2"   => ['OBJ_ID'],
			"SS7LS"      => ['OBJ_ID'],
			"SS7SLTRAFF" => ['OBJ_ID'],
			"SS7SCSUBSY" => ['OBJ_ID'],
			"SS7TT"      => ['OBJ_ID'],
			"SS7PRGRP"   => ['OBJ_ID'],
			"SS7HSLPG1"  => ['OBJ_ID'],
			"SS7HSLPG2"  => ['OBJ_ID'],
			"SDIPMS"     => ['OBJ_ID'],
			"SDIPHP"     => ['OBJ_ID'],
			"SDIPLP"     => ['OBJ_ID'],
			"DIGPATH"    => ['OBJ_ID'],
			"GRPSWITCH"  => ['OBJ_ID'],
			"SNT"        => ['OBJ_ID'],
			"DIGS"       => ['OBJ_ID'],
			"SPDL"       => ['OBJ_ID'],
			"NETWSYNC"   => ['OBJ_ID'],
			"APDISKS"    => ['OBJ_ID'],
			"APPLATFORM" => ['OBJ_ID'],
			"SS7SCCPUSE" => ['OBJ_ID'],
			"SS7SCQOS"   => ['OBJ_ID'],
			"C7SCCPUSE"  => ['OBJ_ID'],
			"C7SCPERF"   => ['OBJ_ID'],
			"C7SCQOS"    => ['OBJ_ID'],
			"ATERTRANS"  => ['OBJ_ID'],
			"BSC"        => ['OBJ_ID'],
			"BSCMSLOT"   => ['OBJ_ID'],
			"BSCPOS"     => ['OBJ_ID'],
			"BSCQOS"     => ['OBJ_ID'],
			"GPHLOADREG" => ['OBJ_ID'],
			"DELSTRTBF"  => ['OBJ_ID'],
			"LOASMISC"   => ['OBJ_ID'],
			"TRALOST"    => ['OBJ_ID'],
			"MSC"        => ['OBJ_ID'],
			"CP"         => ['OBJ_ID'],
			"EMGPRS"     => ['OBJ_ID'],
			"MOTG"       => ['OBJ_ID'],
			"MOTS"       => ['OBJ_ID'],
			"DOWNTIME"   => ['OBJ_ID'],
			"CELEVENTSC" => ['OBJ_ID'],
			"CELLAFFER"  => ['OBJ_ID'],
			"CELLAHFER"  => ['OBJ_ID'],
			"CELLCONF"   => ['OBJ_ID'],
			"CELLDUALT"  => ['OBJ_ID'],
			"CELLEFFER"  => ['OBJ_ID'],
			"CELLFERF"   => ['OBJ_ID'],
			"CELLFERH"   => ['OBJ_ID'],
			"CELLFFER"   => ['OBJ_ID'],
			"CELLFLXAB"  => ['OBJ_ID'],
			"CELLGPRSO"  => ['OBJ_ID'],
			"CELLHFER"   => ['OBJ_ID'],
			"CELLQOSEG"  => ['OBJ_ID'],
			"CELLQOSS"   => ['OBJ_ID'],
			"CELLSQI"    => ['OBJ_ID'],
			"CELLSQIDL"  => ['OBJ_ID'],
			"CLTCHFV1"   => ['OBJ_ID'],
			"CLTCHFV2"   => ['OBJ_ID'],
			"CLTCHHV1"   => ['OBJ_ID'],
			"CLDTMEST"   => ['OBJ_ID'],
			"CLDTMPER"   => ['OBJ_ID'],
			"CLDTMQOS"   => ['OBJ_ID'],
			"CLRATECHG"  => ['OBJ_ID'],
			"CLRXQUAL"   => ['OBJ_ID'],
			"CELEVENTS"  => ['OBJ_ID'],
			"CELLCCHDR"  => ['OBJ_ID'],
			"CELLCCHHO"  => ['OBJ_ID'],
			"CLSDCCH"    => ['OBJ_ID'],
			"CLSDCCHO"   => ['OBJ_ID'],
			"CLSMS"      => ['OBJ_ID'],
			"CELLHCS"    => ['OBJ_ID'],
			"CELTCH"     => ['OBJ_ID'],
			"CLTCHFV3"   => ['OBJ_ID'],
			"CLTCHFV3C"  => ['OBJ_ID'],
			"IDLEOTCHF"  => ['OBJ_ID'],
			"IDLEUTCHF"  => ['OBJ_ID'],
			"IDLEOTCHH"  => ['OBJ_ID'],
			"IDLEUTCHH"  => ['OBJ_ID'],
			"CELLEIT"    => ['OBJ_ID'],
			"CELLEIT2"   => ['OBJ_ID'],
			"CELLGPRS3"  => ['OBJ_ID'],
			"CELLGPRS4"  => ['OBJ_ID'],
			"CELTCHFP"   => ['OBJ_ID'],
			"NUCELLREL"  => ['OBJ_ID'],
			"CELLHSCSD"  => ['OBJ_ID'],
			"PREEMP"     => ['OBJ_ID'],
			"CELLMSQ"    => ['OBJ_ID'],
			"CLQOSSCON"  => ['OBJ_ID'],
			"CLQOSSCON2" => ['OBJ_ID'],
			"CHGRP0SQI"  => ['OBJ_ID'],
			"CHGRP0F"    => ['OBJ_ID'],
			"CHGRP0H"    => ['OBJ_ID'],
			"CLTCHDRAF"  => ['OBJ_ID'],
			"CLTCHDRAH"  => ['OBJ_ID'],
			"CLTCHHV3C"  => ['OBJ_ID'],
			"CLTCHHV3"   => ['OBJ_ID'],
			"RLINKBITR"  => ['OBJ_ID'],
			"NECELLREL"  => ['OBJ_ID'],
			"NECELASS"   => ['OBJ_ID'],
			"NECELHO"    => ['OBJ_ID'],
			"NECELHOEX"  => ['OBJ_ID'],
			"NECELHO"    => ['OBJ_ID'],
			"NICELHOEX"  => ['OBJ_ID'],
			"ABISIP"     => ['OBJ_ID'],
			"NONRES64K"  => ['OBJ_ID'],
			"RES64K"     => ['OBJ_ID'],
			"SUPERCH"    => ['OBJ_ID'],
			"CELLMSCAP"  => ['OBJ_ID'],
############### NEW for R1207B ################
			"SPSP"       => ['OBJ_ID'],
			"PGW"        => ['OBJ_ID'],
			"PGWLDIST"   => ['OBJ_ID'],
			"SUPERCH2"   => ['OBJ_ID'],
			"TRH"        => ['OBJ_ID'],
			"SS7TOTAL"   => ['OBJ_ID'],
			"SS7TOTAL2"  => ['OBJ_ID'],
			"SS7TIMERS"  => ['OBJ_ID'],
			"TCABO"      => ['OBJ_ID'],
			"TCREJ"      => ['OBJ_ID'],
			"TCUSE"      => ['OBJ_ID'],
			"TPLAT"      => ['OBJ_ID'],
			"TCCMP"      => ['OBJ_ID'],
			"TCDIA"      => ['OBJ_ID'],
			"TCMSG"      => ['OBJ_ID'],
			"C7RTTOTAL"  => ['OBJ_ID'],
			"GANDIREPA"  => ['OBJ_ID'],
			"GANRESALL"  => ['OBJ_ID'],
			"GANRPLOAD"  => ['OBJ_ID'],
			"EMG"        => ['OBJ_ID'],
			"EMRP"       => ['OBJ_ID'],
			"CVTR02"     => ['OBJ_ID'],
			"MRVFAIL"    => ['OBJ_ID'],
			"SCTPAM"     => ['OBJ_ID'],
			"SCTPLM"     => ['OBJ_ID'],
			"SS7HSLS"    => ['OBJ_ID'],
			"SS7HSLTRAF" => ['OBJ_ID'],
			"SS7HSLMT1"  => ['OBJ_ID'],
			"SS7HSLMT2"  => ['OBJ_ID'],
			"SS7HSLMT3"  => ['OBJ_ID'],
			"RP"         => ['OBJ_ID'],
			"C7ADJSLP"   => ['OBJ_ID'],
			"C7DPC"      => ['OBJ_ID'],
			"C7OPC"      => ['OBJ_ID'],
############### END ########################
		}
	}
);

sub engine_config {
	return \@rules;
}

1;